@@ -76,7 +76,8 @@ Empirical <- R6Class("Empirical",
     #' The arithmetic mean of a (discrete) probability distribution X is the expectation
     #' \deqn{E_X(X) = \sum p_X(x)*x}
     #' with an integration analogue for continuous distributions.
-    mean = function() {
+    #' @param ... Unused.
+    mean = function(...) {
       return(mean(self$getParameterValue("data")$samples))
     },
 
@@ -97,7 +98,8 @@ Empirical <- R6Class("Empirical",
     #' \deqn{var_X = E[X^2] - E[X]^2}
     #' where \eqn{E_X} is the expectation of distribution X. If the distribution is multivariate the
     #' covariance matrix is returned.
-    variance = function() {
+    #' @param ... Unused.
+    variance = function(...) {
       data <- self$getParameterValue("data")$samples
       return(sum((data - self$mean())^2) / length(data))
     },
@@ -107,7 +109,8 @@ Empirical <- R6Class("Empirical",
     #' \deqn{sk_X = E_X[\frac{x - \mu}{\sigma}^3]}{sk_X = E_X[((x - \mu)/\sigma)^3]}
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
-    skewness = function() {
+    #' @param ... Unused.
+    skewness = function(...) {
       data <- self$getParameterValue("data")$samples
       return(sum(((data - self$mean()) / self$stdev())^3) / length(data))
     },
@@ -118,7 +121,8 @@ Empirical <- R6Class("Empirical",
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
     #' Excess Kurtosis is Kurtosis - 3.
-    kurtosis = function(excess = TRUE) {
+    #' @param ... Unused.
+    kurtosis = function(excess = TRUE, ...) {
       data <- self$getParameterValue("data")$samples
       kurt <- sum(((data - self$mean()) / self$stdev())^4) / length(data)
       if (excess) {
@@ -133,7 +137,8 @@ Empirical <- R6Class("Empirical",
     #' \deqn{- \sum (f_X)log(f_X)}
     #' where \eqn{f_X} is the pdf of distribution X, with an integration analogue for
     #' continuous distributions.
-    entropy = function(base = 2) {
+    #' @param ... Unused.
+    entropy = function(base = 2, ...) {
       data <- self$getParameterValue("data")
       p <- data$N / nrow(data)
       return(-sum(p * log(p, base)))
@@ -142,7 +147,8 @@ Empirical <- R6Class("Empirical",
     #' @description The moment generating function is defined by
     #' \deqn{mgf_X(t) = E_X[exp(xt)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    mgf = function(t) {
+    #' @param ... Unused.
+    mgf = function(t, ...) {
       data <- self$getParameterValue("data")
       if (length(t) == 1) {
         return(sum(exp(data$samples * t) * (data$N / nrow(data))))
@@ -159,7 +165,8 @@ Empirical <- R6Class("Empirical",
     #' @description The characteristic function is defined by
     #' \deqn{cf_X(t) = E_X[exp(xti)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    cf = function(t) {
+    #' @param ... Unused.
+    cf = function(t, ...) {
       data <- self$getParameterValue("data")
       if (length(t) == 1) {
         return(sum(exp(data$samples * t * 1i) * (data$N / nrow(data))))
@@ -176,7 +183,8 @@ Empirical <- R6Class("Empirical",
     #' @description The probability generating function is defined by
     #' \deqn{pgf_X(z) = E_X[exp(z^x)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    pgf = function(z) {
+    #' @param ... Unused.
+    pgf = function(z, ...) {
       data <- self$getParameterValue("data")
       if (length(z) == 1) {
         return(sum((z^data$samples) * (data$N / nrow(data))))
