@@ -116,7 +116,8 @@ WeightedDiscrete <- R6Class("WeightedDiscrete",
     #' The arithmetic mean of a (discrete) probability distribution X is the expectation
     #' \deqn{E_X(X) = \sum p_X(x)*x}
     #' with an integration analogue for continuous distributions.
-    mean = function() {
+    #' @param ... Unused.
+    mean = function(...) {
       x <- self$getParameterValue("x")
       pdf <- self$getParameterValue("pdf")
 
@@ -164,7 +165,8 @@ WeightedDiscrete <- R6Class("WeightedDiscrete",
     #' \deqn{var_X = E[X^2] - E[X]^2}
     #' where \eqn{E_X} is the expectation of distribution X. If the distribution is multivariate the
     #' covariance matrix is returned.
-    variance = function() {
+    #' @param ... Unused.
+    variance = function(...) {
       x <- self$getParameterValue("x")
       pdf <- self$getParameterValue("pdf")
       mean <- self$mean()
@@ -181,7 +183,8 @@ WeightedDiscrete <- R6Class("WeightedDiscrete",
     #' \deqn{sk_X = E_X[\frac{x - \mu}{\sigma}^3]}{sk_X = E_X[((x - \mu)/\sigma)^3]}
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
-    skewness = function() {
+    #' @param ... Unused.
+    skewness = function(...) {
       x <- self$getParameterValue("x")
       pdf <- self$getParameterValue("pdf")
       mean <- self$mean()
@@ -203,7 +206,8 @@ WeightedDiscrete <- R6Class("WeightedDiscrete",
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
     #' Excess Kurtosis is Kurtosis - 3.
-    kurtosis = function(excess = TRUE) {
+    #' @param ... Unused.
+    kurtosis = function(excess = TRUE, ...) {
       x <- self$getParameterValue("x")
       pdf <- self$getParameterValue("pdf")
       mean <- self$mean()
@@ -230,7 +234,8 @@ WeightedDiscrete <- R6Class("WeightedDiscrete",
     #' \deqn{- \sum (f_X)log(f_X)}
     #' where \eqn{f_X} is the pdf of distribution X, with an integration analogue for
     #' continuous distributions.
-    entropy = function(base = 2) {
+    #' @param ... Unused.
+    entropy = function(base = 2, ...) {
       pdf <- self$getParameterValue("pdf")
       if (checkmate::testList(pdf)) {
         return(sapply(pdf, function(x) -sum(x * log(x, base))))
@@ -242,7 +247,8 @@ WeightedDiscrete <- R6Class("WeightedDiscrete",
     #' @description The moment generating function is defined by
     #' \deqn{mgf_X(t) = E_X[exp(xt)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    mgf = function(t) {
+    #' @param ... Unused.
+    mgf = function(t, ...) {
       data <- self$getParameterValue("x")
       pdf <- self$getParameterValue("pdf")
 
@@ -261,7 +267,8 @@ WeightedDiscrete <- R6Class("WeightedDiscrete",
     #' @description The characteristic function is defined by
     #' \deqn{cf_X(t) = E_X[exp(xti)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    cf = function(t) {
+    #' @param ... Unused.
+    cf = function(t, ...) {
       data <- self$getParameterValue("x")
       pdf <- self$getParameterValue("pdf")
 
@@ -280,7 +287,8 @@ WeightedDiscrete <- R6Class("WeightedDiscrete",
     #' @description The probability generating function is defined by
     #' \deqn{pgf_X(z) = E_X[exp(z^x)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    pgf = function(z) {
+    #' @param ... Unused.
+    pgf = function(z, ...) {
       data <- self$getParameterValue("x")
       pdf <- self$getParameterValue("pdf")
 
