@@ -40,25 +40,28 @@ autotest_sdistribution <- function(sdist, pars, traits, support, symmetry,
     expect_equal(names(formals(sdist$public_methods$setParameterValue)), c("...", "lst", "error"))
   }
   expect_true("decorators" %in% names(formals(sdist$public_methods$initialize)))
-  if (!is.null(sdist$public_methods$mean)) expect_null(names(formals(sdist$public_methods$mean)))
+  if (!is.null(sdist$public_methods$mean))
+    expect_equal(names(formals(sdist$public_methods$mean)), "...")
   if (!is.null(sdist$public_methods$mode))
     expect_equal(formals(sdist$public_methods$mode), pairlist(which = "all"))
   if (!is.null(sdist$public_methods$median))
     expect_null(names(formals(sdist$public_methods$median)))
   if (!is.null(sdist$public_methods$variance))
-    expect_null(names(formals(sdist$public_methods$variance)))
+    expect_equal(names(formals(sdist$public_methods$variance)), "...")
   if (!is.null(sdist$public_methods$skewness))
-    expect_null(names(formals(sdist$public_methods$skewness)))
+    expect_equal(names(formals(sdist$public_methods$skewness)), "...")
   if (!is.null(sdist$public_methods$kurtosis))
-    expect_equal(formals(sdist$public_methods$kurtosis), pairlist(excess = TRUE))
+    expect_equal(formals(sdist$public_methods$kurtosis),
+                 as.pairlist(c(pairlist(excess = TRUE), alist(... = ))))
   if (!is.null(sdist$public_methods$entropy))
-    expect_equal(formals(sdist$public_methods$entropy), pairlist(base = 2))
+    expect_equal(formals(sdist$public_methods$entropy),
+                 as.pairlist(c(pairlist(base = 2), alist(... = ))))
   if (!is.null(sdist$public_methods$mgf))
-    expect_equal(names(formals(sdist$public_methods$mgf)), "t")
+    expect_equal(names(formals(sdist$public_methods$mgf)), c("t", "..."))
   if (!is.null(sdist$public_methods$cf))
-    expect_equal(names(formals(sdist$public_methods$cf)), "t")
+    expect_equal(names(formals(sdist$public_methods$cf)), c("t", "..."))
   if (!is.null(sdist$public_methods$pgf))
-    expect_equal(names(formals(sdist$public_methods$pgf)), "z")
+    expect_equal(names(formals(sdist$public_methods$pgf)), c("z", "..."))
 
   # context("private methods")
   checkmate::expect_subset(names(sdist$private_methods), c(
@@ -379,7 +382,8 @@ autotest_kernel <- function(kern, shortname, support, variance, pdfSquared2Norm,
   }
 
   # context("public methods")
-  checkmate::expect_subset(names(kern$public_methods), c("clone", "pdfSquared2Norm", "variance",
+  checkmate::expect_subset(names(kern$public_methods), c("clone", "pdfSquared2Norm",
+                                                         "cdfSquared2Norm", "variance",
                                                          "initialize"))
 
   if (!is.null(kern$public_methods$setParameterValue)) {
@@ -387,21 +391,14 @@ autotest_kernel <- function(kern, shortname, support, variance, pdfSquared2Norm,
   }
   # expect_equal(formals(kern$public_methods$initialize), pairlist(decorators = NULL))
   if (!is.null(kern$public_methods$pdfSquared2Norm)) {
-    expect_equal(formals(kern$public_methods$pdfSquared2Norm), pairlist(x = 0))
+    expect_equal(formals(kern$public_methods$pdfSquared2Norm), pairlist(x = 0, upper = Inf))
+  }
+  if (!is.null(kern$public_methods$cdfSquared2Norm)) {
+    expect_equal(formals(kern$public_methods$cdfSquared2Norm), pairlist(x = 0, upper = 0))
   }
   if (!is.null(kern$public_methods$variance))
-    expect_null(names(formals(kern$public_methods$variance)))
-  if (!is.null(kern$public_methods$skewness))
-    expect_null(names(formals(kern$public_methods$skewness)))
-  if (!is.null(kern$public_methods$kurtosis))
-    expect_equal(formals(kern$public_methods$kurtosis), pairlist(excess = TRUE))
-  if (!is.null(kern$public_methods$entropy))
-    expect_equal(formals(kern$public_methods$entropy), pairlist(base = 2))
-  if (!is.null(kern$public_methods$mgf)) expect_equal(names(formals(kern$public_methods$mgf)), "t")
-  if (!is.null(kern$public_methods$cf)) expect_equal(names(formals(kern$public_methods$cf)), "t")
-  if (!is.null(kern$public_methods$pgf)) expect_equal(names(formals(kern$public_methods$pgf)), "z")
+    expect_equal(names(formals(kern$public_methods$variance)), "...")
 
-  # context("private methods")
   checkmate::expect_subset(names(kern$private_methods), c(".pdf", ".cdf", ".quantile", ".rand"))
 
   checkmate::expect_subset(names(formals(kern$private_methods$.pdf)), c("x", "log"))
